package com.phm.manage.service;

import com.phm.manage.domain.FaultAnalyzeResult;

import java.util.List;

/**
 * 故障分析结果Service接口
 *
 * @author phm
 * @date 2023-08-22
 */
public interface IFaultAnalyzeResultService {
    /**
     * 查询故障分析结果
     *
     * @param id 故障分析结果主键
     * @return 故障分析结果
     */
    public FaultAnalyzeResult selectFaultAnalyzeResultById(Long id);

    /**
     * 查询故障分析结果列表
     *
     * @param faultAnalyzeResult 故障分析结果
     * @return 故障分析结果集合
     */
    public List<FaultAnalyzeResult> selectFaultAnalyzeResultList(FaultAnalyzeResult faultAnalyzeResult);

    /**
     * 新增故障分析结果
     *
     * @param faultAnalyzeResult 故障分析结果
     * @return 结果
     */
    public int insertFaultAnalyzeResult(FaultAnalyzeResult faultAnalyzeResult);

    /**
     * 修改故障分析结果
     *
     * @param faultAnalyzeResult 故障分析结果
     * @return 结果
     */
    public int updateFaultAnalyzeResult(FaultAnalyzeResult faultAnalyzeResult);

    /**
     * 批量删除故障分析结果
     *
     * @param ids 需要删除的故障分析结果主键集合
     * @return 结果
     */
    public int deleteFaultAnalyzeResultByIds(Long[] ids);

    /**
     * 删除故障分析结果信息
     *
     * @param id 故障分析结果主键
     * @return 结果
     */
    public int deleteFaultAnalyzeResultById(Long id);
}
